==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'P&aacute;gina de abertura do s&iacute;tio',
'articles' => 'Artigos',
'articles_auteur' => 'Artigos deste autor',
'articles_populaires' => 'Artigos mais populares',
'articles_rubrique' => 'Artigos desta rubrica',
'aucun_article' => 'Nenhum artigo neste endere&ccedil;o',
'aucun_auteur' => 'Nenhum autor neste endere&ccedil;o',
'aucun_site' => 'Nenhum s&iacute;tio neste endere&ccedil;o',
'aucune_breve' => 'Nenhuma not&iacute;cia neste endere&ccedil;o',
'aucune_rubrique' => 'Nenhuma rubrica neste endere&ccedil;o',
'autres_breves' => 'Outras not&iacute;cias',
'autres_groupes_mots_clefs' => 'Outros grupos de palavras-chave',
'autres_sites' => 'Outros s&iacute;tios',

// B
'bonjour' => 'Bom dia',
'breves' => 'Not&iacute;cias',

// C
'commenter_site' => 'Comentar este s&iacute;tio',

// D
'date' => 'Data',
'dernier_ajout' => '&Uacute;ltima actualiza&ccedil;&atilde;o',
'dernieres_breves' => '&Uacute;ltimas not&iacute;cias',
'derniers_articles' => '&Uacute;ltimos artigos',
'derniers_commentaires' => '&Uacute;ltimos coment&aacute;rios',
'derniers_messages_forum' => '&Uacute;ltimas mensagens publicadas nos f&oacute;runs',

// E
'edition_mode_texte' => 'Edi&ccedil;&atilde;o em modo texto de',
'en_reponse' => 'Em resposta a&nbsp;:',
'en_resume' => 'Em resumo',
'envoyer_message' => 'Enviar uma mensagem',
'espace_prive' => 'Espa&ccedil;o privado',

// F
'forum' => 'F&oacute;rum',

// H
'hierarchie_site' => 'Hierarquia do s&iacute;tio',

// J
'jours' => 'dias',

// M
'meme_auteur' => 'Do mesmo autor',
'meme_rubrique' => 'Na mesma rubrica',
'memes_auteurs' => 'Dos mesmos autores',
'message' => 'Mensagem',
'messages_forum' => 'Mensagens de f&oacute;rum',
'messages_recents' => 'Mensagens de f&oacute;runs mais recentes',
'mots_clefs' => 'Palavras-chave',
'mots_clefs_meme_groupe' => 'Palavras-chave no mesmo grupo',

// N
'navigation' => 'Navega&ccedil;&atilde;o',
'nom' => 'Nome',
'nouveautes' => 'As novidades',
'nouveautes_web' => 'Novidades na Web',
'nouveaux_articles' => 'Novos artigos',
'nouvelles_breves' => 'Novas not&iacute;cias',

// P
'page_precedente' => 'p&aacute;gina anterior',
'page_suivante' => 'p&aacute;gina seguinte',
'par_auteur' => 'por',
'participer_site' => 'Pode participar na vida deste s&iacute;tio e propor os seus pr&oacute;prios artigos, inscrevendo-se mais abaixo. Receber&aacute; imediatamente um email que indica os seus c&oacute;digos de acesso ao espa&ccedil;o privado do s&iacute;tio.',
'plan_site' => 'Planta do s&iacute;tio',
'popularite' => 'Popularidade',
'poster_message' => 'Enviar uma mensagem',
'proposer_site' => 'Voc&ecirc; pode propor um s&iacute;tio a adicionar a esta rubrica&nbsp;:',

// R
'repondre_article' => 'Responder a este artigo',
'repondre_breve' => 'Responder a esta not&iacute;cia',
'repondre_message' => 'Responder a esta mensagem',
'resultats_recherche' => 'Resultados da pesquisa',
'retour_debut_forums' => 'Regresso ao in&iacute;cio dos f&oacute;runs',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Assinaturas',
'site_realise_avec_spip' => 'S&iacute;tio realizado com SPIP',
'sites_web' => 'S&iacute;tios Web',
'sous_rubriques' => 'Sub-rubricas',
'suite' => 'continua&ccedil;&atilde;o',
'sur_web' => 'Na Web',
'syndiquer_rubrique' => 'Vincular esta rubrica',
'syndiquer_site' => 'Vincular todo o s&iacute;tio',

// T
'texte_lettre_information' => 'Eis a carta de informa&ccedil;&atilde;o do s&iacute;tio',
'texte_lettre_information_2' => 'Esta carta recenseia os artigos e as not&iacute;cias publicados desde',

// V
'ver_imprimer' => 'Vers&atilde;o para imprimir',
'voir_en_ligne' => 'Ver em linha',
'voir_squelette' => 'importar o esqueleto desta p&aacute;gina'
);

?>

==> spip_2.1.1.orig.tar.gz: spip-2.1.1/ecrire/lang/public_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'P&aacute;gina de abertura do s&iacute;tio',
'article' => 'Article', # NEW
'articles' => 'Artigos',
'articles_auteur' => 'Artigos deste autor',
'articles_populaires' => 'Artigos mais populares',
'articles_rubrique' => 'Artigos desta rubrica',
'aucun_article' => 'Nenhum artigo neste endere&ccedil;o',
'aucun_auteur' => 'Nenhum autor neste endere&ccedil;o',
'aucun_site' => 'Nenhum s&iacute;tio neste endere&ccedil;o',
'aucune_breve' => 'Nenhuma not&iacute;cia neste endere&ccedil;o',
'aucune_rubrique' => 'Nenhuma rubrica neste endere&ccedil;o',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => 'Outras not&iacute;cias',
'autres_groupes_mots_clefs' => 'Outros grupos de palavras-chave',
'autres_sites' => 'Outros s&iacute;tios',

// B
'bonjour' => 'Bom dia',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Not&iacute;cias',

// C
'commenter_site' => 'Comentar este s&iacute;tio',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => 'Data',
'dernier_ajout' => '&Uacute;ltima actualiza&ccedil;&atilde;o',
'dernieres_breves' => '&Uacute;ltimas not&iacute;cias',
'derniers_articles' => '&Uacute;ltimos artigos',
'derniers_commentaires' => '&Uacute;ltimos coment&aacute;rios',
'derniers_messages_forum' => '&Uacute;ltimas mensagens publicadas nos f&oacute;runs',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'Edi&ccedil;&atilde;o em modo texto de',
'en_reponse' => 'Em resposta a&nbsp;:',
'en_resume' => 'Em resumo',
'envoyer_message' => 'Enviar uma mensagem',
'espace_prive' => 'Espa&ccedil;o privado',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'F&oacute;rum',

// H
'hierarchie_site' => 'Hierarquia do s&iacute;tio',

// J
'jours' => 'dias',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'Do mesmo autor',
'meme_rubrique' => 'Na mesma rubrica',
'memes_auteurs' => 'Dos mesmos autores',
'message' => 'Mensagem',
'messages_forum' => 'Mensagens de f&oacute;rum',
'messages_recents' => 'Mensagens de f&oacute;runs mais recentes',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Palavras-chave',
'mots_clefs_meme_groupe' => 'Palavras-chave no mesmo grupo',

// N
'navigation' => 'Navega&ccedil;&atilde;o',
'nom' => 'Nome',
'nouveautes' => 'As novidades',
'nouveautes_web' => 'Novidades na Web',
'nouveaux_articles' => 'Novos artigos',
'nouvelles_breves' => 'Novas not&iacute;cias',

// P
'page_precedente' => 'p&aacute;gina anterior',
'page_suivante' => 'p&aacute;gina seguinte',
'par_auteur' => 'por',
'participer_site' => 'Pode participar na vida deste s&iacute;tio e propor os seus pr&oacute;prios artigos, inscrevendo-se mais abaixo. Receber&aacute; imediatamente um email que indica os seus c&oacute;digos de acesso ao espa&ccedil;o privado do s&iacute;tio.',
'plan_site' => 'Planta do s&iacute;tio',
'popularite' => 'Popularidade',
'poster_message' => 'Enviar uma mensagem',
'proposer_site' => 'Voc&ecirc; pode propor um s&iacute;tio a adicionar a esta rubrica&nbsp;:',

// R
'repondre_article' => 'Responder a este artigo',
'repondre_breve' => 'Responder a esta not&iacute;cia',
'repondre_message' => 'Responder a esta mensagem',
'resultats_recherche' => 'Resultados da pesquisa',
'retour_debut_forums' => 'Regresso ao in&iacute;cio dos f&oacute;runs',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Assinaturas',
'site_realise_avec_spip' => 'S&iacute;tio realizado com SPIP',
'sites_web' => 'S&iacute;tios Web',
'sous_rubriques' => 'Sub-rubricas',
'spam' => 'Spam', # NEW
'suite' => 'continua&ccedil;&atilde;o',
'sur_web' => 'Na Web',
'syndiquer_rubrique' => 'Vincular esta rubrica',
'syndiquer_site' => 'Vincular todo o s&iacute;tio',

// T
'texte_lettre_information' => 'Eis a carta de informa&ccedil;&atilde;o do s&iacute;tio',
'texte_lettre_information_2' => 'Esta carta recenseia os artigos e as not&iacute;cias publicados desde',

// V
'ver_imprimer' => 'Vers&atilde;o para imprimir',
'voir_en_ligne' => 'Ver em linha',
'voir_squelette' => 'importar o esqueleto desta p&aacute;gina', # MODI
);

?>
